==> ttyrpld-2.03.4.tar.bz2: ttyrpld-2.03.4/doc/netlog.php <==
<?php include_once("_header.php"); ?>
  <tr>
    <td align="right" valign="top"
      class="section"><b>Description&nbsp;&gt;</b></td>
    <td valign="top">

      <p class="block">There is a simple way on how to scoop <tt>/dev/rpl</tt>
      data directly to another host without logging it on the one where it was
      captured. This is commonly referred to as "network logging".</p>

      <p class="block"><i>Note right at the start:</i> It is not very useful to
      transfer between different operating systems, because each has completely
      different major numbers for different ttys, so running <i>rpld</i> on
      Linux and feeding it input from a FreeBSD capturer will yield wrong
      terminal names.</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>
    <td align="right" valign="top"
      class="section"><b>Setup&nbsp;&gt;</b></td>
    <td valign="top">

      <p class="block">Beginning with <i>ttyrpld 2.00</i>, the timestamp is
      added in kernelspace, so that you can directly <tt>cat /dev/rpl</tt> to a
      file and process it <u>later</u>. The "later" was not possible before
      ttyrpld 2.00. Therefore, the remote capture process has become extremely
      simple. Run this on the capture host:</p>

      <div class="indent">
        <p class="code"><tt># <b>ssh -Te none daemon@storage "rpld -D -"
        &lt;/dev/rpl</b></tt></p>
      </div>

      <p class="block">You might want to use a different account name for
      ssh'ing (because <tt>daemon</tt> is a system account and remote logins
      for this "user" would look like an intrusion). I also suggest using SSH
      keys so that you do not need to enter the password all the time you
      connect.</p>

    </td>
  </tr>
<?php include_once("_footer.php"); ?>

==> ttyrpld-2.10.tar.bz2: ttyrpld-2.10/doc/netlog.php <==
<?php include_once("_header.php"); ?>
  <tr>
    <td align="right" valign="top"
      class="section"><b>Description&nbsp;&gt;</b></td>
    <td valign="top">

      <p class="block">There is a simple way on how to scoop <tt>/dev/rpl</tt>
      data directly to another host without logging it on the one where it was
      captured. This is commonly referred to as "network logging".</p>

      <p class="block"><i>Note right at the start:</i> It is not very useful to
      transfer between different operating systems, because each has completely
      different major numbers for different ttys, so running <i>rpld</i> on
      Linux and feeding it input from a FreeBSD capturer will yield wrong
      terminal names.</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>
    <td align="right" valign="top"
      class="section"><b>Setup&nbsp;&gt;</b></td>
    <td valign="top">

      <p class="block">Beginning with <i>ttyrpld 2.00</i>, the timestamp is
      added in kernelspace, so that you can directly <tt>cat /dev/rpl</tt> to a
      file and process it <u>later</u>. The "later" was not possible before
      ttyrpld 2.00. Therefore, the remote capture process has become extremely
      simple. Run this on the capture host:</p>

      <div class="indent">
        <p class="code"><tt># <b>ssh -Te none daemon@storage "rpld -D -"
        &lt;/dev/rpl</b></tt></p>
      </div>

      <p class="block">You might want to use a different account name for
      ssh'ing (because <tt>daemon</tt> is a system account and remote logins
      for this "user" would look like an intrusion). I also suggest using SSH
      keys so that you do not need to enter a password when you connect.</p>

    </td>
  </tr>
<?php include_once("_footer.php"); ?>
